@@ -128,21 +128,22 @@
 #include <ctype.h> /* for yylex alnum */
 #include "calc.h"  /* Contains definition of `symrec'.  */
 #include "tmpllog.h"
-/* for expr-specific only */
 #include "pabstract.h"
 #include "prostate.h"
 #include "provalue.h"
+#include "pparam.h"
+#include "pmiscdef.h"
+/* for expr-specific only */
 #include "exprtool.h"
 #include "exprpstr.h"
 #include "parse_expr.h"
-#include "pparam.h"
   /* kill them.
 Debug Assertion Failed! f:\dd\vctools\crt_bld\self_x86\crt\src \isctype.c Expression:(unsigned)(c + 1) <= 256 
    */
 #ifdef _MSC_VER
-#  define TO_UNSIGNED_CHAR (unsigned char)
+#  define TO_UNSIGNED_CHAR(X) ((unsigned char) (X))
 #else
-#  define TO_UNSIGNED_CHAR
+#  define TO_UNSIGNED_CHAR(X) X
 #endif
   
 
@@ -166,14 +167,14 @@ Debug Assertion Failed! f:\dd\vctools\crt_bld\self_x86\crt\src \isctype.c Expres
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 29 "expr.y"
+#line 30 "expr.y"
 {
   struct exprval numval;   /* For returning numbers.  */
   const symrec_const  *tptr;   /* For returning symbol-table pointers.  */
   struct user_func_call extfunc;  /* for user-defined function name */
 }
 /* Line 193 of yacc.c.  */
-#line 177 "y.tab.c"
+#line 178 "y.tab.c"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -183,7 +184,7 @@ typedef union YYSTYPE
 
 
 /* Copy the second part of user declarations.  */
-#line 34 "expr.y"
+#line 35 "expr.y"
 
   /* the second section is required as we use YYSTYPE here */
   static void yyerror (struct tmplpro_state* state, PSTRING* expr_retval_ptr, char const *);
@@ -191,7 +192,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 195 "y.tab.c"
+#line 196 "y.tab.c"
 
 #ifdef short
 # undef short
@@ -491,10 +492,10 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    58,    58,    73,    74,    76,    80,    85,    91,    92,
-      93,    94,   125,   137,   148,   154,   155,   156,   157,   158,
-     159,   160,   161,   162,   163,   164,   165,   169,   170,   171,
-     172,   173,   174,   175,   176,   179,   184
+       0,    59,    59,    74,    75,    77,    81,    86,    92,    93,
+      94,    95,   126,   138,   149,   155,   156,   157,   158,   159,
+     160,   161,   162,   163,   164,   165,   166,   170,   171,   172,
+     173,   174,   175,   176,   177,   180,   185
 };
 #endif
 
@@ -1490,7 +1491,7 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 59 "expr.y"
+#line 60 "expr.y"
     { 
 		   /* TODO: move to exprtool.inc as expr_to_str1 */
 		   if (EXPR_TYPE_PSTR == (yyvsp[(1) - (1)].numval).type) {
@@ -1505,24 +1506,24 @@ yyreduce:
     break;
 
   case 3:
-#line 73 "expr.y"
+#line 74 "expr.y"
     { (yyval.numval) = (yyvsp[(1) - (1)].numval);			}
     break;
 
   case 4:
-#line 74 "expr.y"
+#line 75 "expr.y"
     { (yyval.numval).type=EXPR_TYPE_DBL; (yyval.numval).val.dblval = (yyvsp[(1) - (1)].tptr)->var; }
     break;
 
   case 5:
-#line 77 "expr.y"
+#line 78 "expr.y"
     {
 		   (yyval.numval) = call_expr_userfunc(state, (yyvsp[(1) - (2)].extfunc));
 		 }
     break;
 
   case 6:
-#line 81 "expr.y"
+#line 82 "expr.y"
     {
 		   (yyvsp[(1) - (3)].extfunc).arglist=state->param->InitExprArglistFuncPtr(state->param->ext_calluserfunc_state);
 		   (yyval.numval) = call_expr_userfunc(state, (yyvsp[(1) - (3)].extfunc));
@@ -1530,7 +1531,7 @@ yyreduce:
     break;
 
   case 7:
-#line 86 "expr.y"
+#line 87 "expr.y"
     {
 		   (yyval.numval).type=EXPR_TYPE_DBL;
 		   expr_to_dbl1(state, &(yyvsp[(3) - (4)].numval));
@@ -1539,22 +1540,22 @@ yyreduce:
     break;
 
   case 8:
-#line 91 "expr.y"
+#line 92 "expr.y"
     { DO_MATHOP(state, (yyval.numval),+,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval));	}
     break;
 
   case 9:
-#line 92 "expr.y"
+#line 93 "expr.y"
     { DO_MATHOP(state, (yyval.numval),-,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval));	}
     break;
 
   case 10:
-#line 93 "expr.y"
+#line 94 "expr.y"
     { DO_MATHOP(state, (yyval.numval),*,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval));	}
     break;
 
   case 11:
-#line 95 "expr.y"
+#line 96 "expr.y"
     { 
 		   (yyval.numval).type=EXPR_TYPE_INT;
 		   expr_to_int(state, &(yyvsp[(1) - (3)].numval),&(yyvsp[(3) - (3)].numval));
@@ -1563,7 +1564,7 @@ yyreduce:
     break;
 
   case 12:
-#line 126 "expr.y"
+#line 127 "expr.y"
     {
 		   (yyval.numval).type=EXPR_TYPE_DBL;
 		   expr_to_dbl(state, &(yyvsp[(1) - (3)].numval),&(yyvsp[(3) - (3)].numval));
@@ -1578,7 +1579,7 @@ yyreduce:
     break;
 
   case 13:
-#line 138 "expr.y"
+#line 139 "expr.y"
     { 
 		   switch ((yyval.numval).type=(yyvsp[(2) - (2)].numval).type) {
 		   case EXPR_TYPE_INT: 
@@ -1592,7 +1593,7 @@ yyreduce:
     break;
 
   case 14:
-#line 149 "expr.y"
+#line 150 "expr.y"
     { 
 		   (yyval.numval).type=EXPR_TYPE_DBL;
 		   expr_to_dbl(state, &(yyvsp[(1) - (3)].numval),&(yyvsp[(3) - (3)].numval));
@@ -1601,62 +1602,62 @@ yyreduce:
     break;
 
   case 15:
-#line 154 "expr.y"
+#line 155 "expr.y"
     { DO_LOGOP(state, (yyval.numval),&&,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval));	}
     break;
 
   case 16:
-#line 155 "expr.y"
+#line 156 "expr.y"
     { DO_LOGOP(state, (yyval.numval),||,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval));	}
     break;
 
   case 17:
-#line 156 "expr.y"
+#line 157 "expr.y"
     { DO_CMPOP(state, (yyval.numval),>=,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval));	}
     break;
 
   case 18:
-#line 157 "expr.y"
+#line 158 "expr.y"
     { DO_CMPOP(state, (yyval.numval),<=,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval));	}
     break;
 
   case 19:
-#line 158 "expr.y"
+#line 159 "expr.y"
     { DO_CMPOP(state, (yyval.numval),!=,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval));	}
     break;
 
   case 20:
-#line 159 "expr.y"
+#line 160 "expr.y"
     { DO_CMPOP(state, (yyval.numval),==,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval));	}
     break;
 
   case 21:
-#line 160 "expr.y"
+#line 161 "expr.y"
     { DO_CMPOP(state, (yyval.numval),>,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval));	}
     break;
 
   case 22:
-#line 161 "expr.y"
+#line 162 "expr.y"
     { DO_CMPOP(state, (yyval.numval),<,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval));	}
     break;
 
   case 23:
-#line 162 "expr.y"
-    { DO_LOGOP1((yyval.numval),!,(yyvsp[(2) - (2)].numval));		}
-    break;
-
-  case 24:
 #line 163 "expr.y"
     { DO_LOGOP1((yyval.numval),!,(yyvsp[(2) - (2)].numval));		}
     break;
 
-  case 25:
+  case 24:
 #line 164 "expr.y"
+    { DO_LOGOP1((yyval.numval),!,(yyvsp[(2) - (2)].numval));		}
+    break;
+
+  case 25:
+#line 165 "expr.y"
     { (yyval.numval) = (yyvsp[(2) - (3)].numval);			}
     break;
 
   case 26:
-#line 165 "expr.y"
+#line 166 "expr.y"
     { 
   expr_to_str(&(yyvsp[(1) - (3)].numval),&(yyvsp[(3) - (3)].numval), state->param); 
   (yyval.numval).type=EXPR_TYPE_INT; (yyval.numval).val.intval = pstring_ge ((yyvsp[(1) - (3)].numval).val.strval,(yyvsp[(3) - (3)].numval).val.strval)-pstring_le ((yyvsp[(1) - (3)].numval).val.strval,(yyvsp[(3) - (3)].numval).val.strval);
@@ -1664,47 +1665,47 @@ yyreduce:
     break;
 
   case 27:
-#line 169 "expr.y"
+#line 170 "expr.y"
     { DO_TXTOP((yyval.numval),pstring_ge,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval),state->param);}
     break;
 
   case 28:
-#line 170 "expr.y"
+#line 171 "expr.y"
     { DO_TXTOP((yyval.numval),pstring_le,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval),state->param);}
     break;
 
   case 29:
-#line 171 "expr.y"
+#line 172 "expr.y"
     { DO_TXTOP((yyval.numval),pstring_ne,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval),state->param);}
     break;
 
   case 30:
-#line 172 "expr.y"
+#line 173 "expr.y"
     { DO_TXTOP((yyval.numval),pstring_eq,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval),state->param);}
     break;
 
   case 31:
-#line 173 "expr.y"
+#line 174 "expr.y"
     { DO_TXTOP((yyval.numval),pstring_gt,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval),state->param);}
     break;
 
   case 32:
-#line 174 "expr.y"
+#line 175 "expr.y"
     { DO_TXTOP((yyval.numval),pstring_lt,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval),state->param);}
     break;
 
   case 33:
-#line 175 "expr.y"
+#line 176 "expr.y"
     { DO_TXTOP((yyval.numval),re_like,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval),state->param);}
     break;
 
   case 34:
-#line 176 "expr.y"
+#line 177 "expr.y"
     { DO_TXTOP((yyval.numval),re_notlike,(yyvsp[(1) - (3)].numval),(yyvsp[(3) - (3)].numval),state->param);}
     break;
 
   case 35:
-#line 179 "expr.y"
+#line 180 "expr.y"
     {
   (yyvsp[(1) - (3)].extfunc).arglist=state->param->InitExprArglistFuncPtr(state->param->expr_func_map);
   pusharg_expr_userfunc(state,(yyvsp[(1) - (3)].extfunc),(yyvsp[(3) - (3)].numval));
@@ -1713,13 +1714,13 @@ yyreduce:
     break;
 
   case 36:
-#line 184 "expr.y"
+#line 185 "expr.y"
     { pusharg_expr_userfunc(state,(yyvsp[(1) - (3)].extfunc),(yyvsp[(3) - (3)].numval)); (yyval.extfunc) = (yyvsp[(1) - (3)].extfunc);	}
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1723 "y.tab.c"
+#line 1724 "y.tab.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1933,7 +1934,7 @@ yyreturn:
 }
 
 
-#line 188 "expr.y"
+#line 189 "expr.y"
 
 
 /* Called by yyparse on error.  */
@@ -1993,7 +1994,10 @@ parse_expr(PSTRING expression, struct tmplpro_state* state)
 static
 void 
 expr_debug(struct tmplpro_state* state, char const *msg1, char const *msg2) {
-  tmpl_log(NULL, TMPL_LOG_ERROR, "EXPR:at pos %td [%td]: %s %s\n", (state->expr_curpos)-(state->top),(state->expr_curpos)-(state->expr).begin,msg1,msg2);
+  tmpl_log(NULL, TMPL_LOG_ERROR, "EXPR:at pos " MOD_TD " [" MOD_TD "]: %s %s\n", 
+	   TO_PTRDIFF_T((state->expr_curpos)-(state->top)),
+	   TO_PTRDIFF_T((state->expr_curpos)-(state->expr).begin),
+	   msg1,msg2);
 }
 
 static
@@ -2030,7 +2034,7 @@ static
 int 
 is_alnum_lex (char c)
 {
-  return (c == '_' || isalnum (TO_UNSIGNED_CHAR c));
+  return (c == '_' || isalnum (TO_UNSIGNED_CHAR(c)));
 }
 
 static 
@@ -2087,7 +2091,7 @@ yylex (YYSTYPE *lvalp, struct tmplpro_state* state)
 	
   state->is_expect_quote_like=0;
   /* Char starts a number => parse the number.         */
-  if (c == '.' || isdigit (TO_UNSIGNED_CHAR c))
+  if (c == '.' || isdigit (TO_UNSIGNED_CHAR(c)))
     {
       (*lvalp).numval=exp_read_number (state, &(state->expr_curpos), (state->expr).endnext);
       return NUM;
